@@ -32,9 +32,14 @@ rsvidx.lsh_add.restype = None
 rsvidx.lsh_custom_hash_add.argtypes = [c_void_p, c_char_p, c_void_p, c_size_t]
 rsvidx.lsh_custom_hash_add.restype = None
 
+
+
 rsvidx.lsh_get.argtypes = [c_void_p, c_void_p, c_ulong, c_void_p]
 rsvidx.lsh_get.restype = c_ulong
 
+rsvidx.lsh_custom_hash_get.argtypes = [c_void_p, c_size_t, c_ulong, c_void_p]
+rsvidx.lsh_custom_hash_get.restype = c_ulong
+
 rsvidx.lsh_delete_helper.argtypes = [c_void_p, c_char_p]
 rsvidx.lsh_delete_helper.restype = None
 
@@ -97,6 +102,21 @@ class Similarity:
 
 		return [raidb.get(self, i)  for i in range(result_size)]
 		
+	def get_custom_hash(self, hash: int, limit: int = 100):
+		buffer_size = (id_size + (sizeof(c_float) * self._dimensions)) * limit
+		buffer = create_string_buffer(buffer_size)
+		result_size = rsvidx.lsh_custom_hash_get(
+			self._idx,
+			hash,
+			limit,
+			buffer
+		)
+		
+		raidb = RandomAccessIDBuffer(buffer)
+
+		return [raidb.get(self, i)  for i in range(result_size)]
+		
+		
 	def remove(self, id: str):
 		rsvidx.lsh_delete_helper(self._idx, bytes(id, "utf-8"))
 		
